async fn deliver_via_mailboxes<I>(
destination: &str,
message: &Message,
friend: &Friend,
context: &CommandContext,
providers: I,
) -> Result<()>where
I: IntoIterator<Item = PeerId>,Expand description
Delivers a message to a set of mailbox providers.
Arguments
destination- The display name or PeerId of the recipient.message- The message to deliver.friend- TheFriendobject of the recipient.context- TheCommandContextfor network interaction and chat output.providers- An iterator overPeerIds of mailbox providers.
Errors
This function returns an error if the underlying mailbox forwarding fails.